Class: TTY::Command::Window::InputRouter::Entry

Inherits:
Struct
  • Object
show all
Defined in:
lib/tty/command/window/input_router.rb

Overview

One attached interactive window: the block that owns the focus flag, the session keystrokes are written to, and the coordinator to repaint on focus changes.

Instance Attribute Summary collapse

Instance Attribute Details

#blockObject

Returns the value of attribute block

Returns:

  • (Object)

    the current value of block



32
33
34
# File 'lib/tty/command/window/input_router.rb', line 32

def block
  @block
end

#coordinatorObject

Returns the value of attribute coordinator

Returns:

  • (Object)

    the current value of coordinator



32
33
34
# File 'lib/tty/command/window/input_router.rb', line 32

def coordinator
  @coordinator
end

#sessionObject

Returns the value of attribute session

Returns:

  • (Object)

    the current value of session



32
33
34
# File 'lib/tty/command/window/input_router.rb', line 32

def session
  @session
end