Class: TTY::Command::Window::InputRouter::Entry
- Inherits:
-
Struct
- Object
- Struct
- TTY::Command::Window::InputRouter::Entry
- Defined in:
- lib/tty/command/window/input_router.rb
Overview
One attached interactive window: the block that owns the focus flag, the session keystrokes are written to, and the coordinator to repaint on focus changes.
Instance Attribute Summary collapse
-
#block ⇒ Object
Returns the value of attribute block.
-
#coordinator ⇒ Object
Returns the value of attribute coordinator.
-
#session ⇒ Object
Returns the value of attribute session.
Instance Attribute Details
#block ⇒ Object
Returns the value of attribute block
32 33 34 |
# File 'lib/tty/command/window/input_router.rb', line 32 def block @block end |
#coordinator ⇒ Object
Returns the value of attribute coordinator
32 33 34 |
# File 'lib/tty/command/window/input_router.rb', line 32 def coordinator @coordinator end |
#session ⇒ Object
Returns the value of attribute session
32 33 34 |
# File 'lib/tty/command/window/input_router.rb', line 32 def session @session end |